homology.PersDiag.transform — GDA Toolbox v1.0 Manual

# homology.PersDiag.transform

`PersDiag.` `transform`(transform=None, points=None)

  Produce an array of points, obtained by transforming the persistence diagram.

  If transform==None [default], then we leave the diagram alone. (birth, death) If transform==”project”, then we project the diagram so that (birth, death) –> (birth, death-birth) = (birth, pers) If transform==”rotate”, then we rotate-and-rescale so that (birth, death) –> ( (death+birth)/2, (death-birth)/2 ) If transform is a 2x2 array, apply it.

  If provided with an array “points”, transform that instead of the diagram.

#### Previous topic

homology.PersDiag.syzygy

#### Next topic

multidim.fast_algorithms